# A Breathless And Brief Introduction To Stand Development


**WARNING**:  *What follows is for the advanced darkroom practitioner.
              It is not for beginners and people should be well
              acquainted with safety and good darkroom practices.
              If you do not already have a least one film/developer
              combination "dialed in", don't bother with any of this.*

**NOTE**:  Please note that I periodically update this document with
           new findings.  If you've already read it in the past,
           you can skip to the [Updates](#updates) section at the end
           of this document


## Precis

Low- or no agitation "stand" techniques have been around since
the beginning of photography.  These techniques are controversial
among very fine photographers.   I set out to test this for myself.

**The Short Version**: True stand development (no agitation after
initial) does not work reliably with modern films.  Infrequent
agitation can be made to work reliably and produces useful results
... at least for me.


## Introduction

I've been a black and white silver photographer for over four decades.
In that time, I've worked with a large number of films and developers,
eventually settling down on a few combinations that worked well for
me.  In every case, I managed time and temperature and agitated the
film according to the developer manufacturer's instructions.

Recently, I became aware of a newish staining developer called "Pyrocat-HD",
invented by Sandy King.  This developer has a great many claimed
virtues among them:

* Semi compensating in the highlights with VC papers
* Tight grain comparable to PMK Pyro
* Much lower sensitivity to oxidation effects than PMK Pyro
* Much less fussy about agitation than PMK Pyro
* Produces negatives that work well for both traditional silver and alternative printing processes

This monograph is *not* about Pyrocat-HD, although all the testing was
done with it.  Pyrocat-HD turned out to be a gateway drug to my
learning about "stand" or "still" development.  This is an an old
technique used by some of the masters like Atget.  Today's modern
masters like Sandy King and Steve Sherman are making use of variations
of stand development to great advantage.  But, in the words of Sandy
King, "It is fraught with danger". The technique is tricky and prone
to failing rather horribly.  So ... **don't try this with pictures
that matter to you without making backup negatives.** I promise you're
going to mess some of them up.

Be aware that the discussion of still development techniques launches
all kinds of religious debates. This is particularly true on the
internet, where everyone is an expert.  I got interested in this
because some very fine photographers make good use of it.  On the other
hand, some very fine photographers think it is nonsense.

There are also people out there claiming this is THE best way to develop
everything.  These people, in particular, are just ... wrong.  Still
development *may* have a place in your workflow if you have the
patience to learn how do it repeatably *and* have subjects that would
benefit from this *and* you are using formats and film that will work
this way.


## Why Bother?

When stand (or one of its variants) works, it gives you negatives of
great apparent accutance, full box ASA speed and - this was most
important to me - a way to increase mid-tone contrast without blowing
out the highlights.  It is mid-tone contrast that gives prints that
"snap" we're always looking for. David Kachel has a very good
commentary on this:

[http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/PrimacyOfLocalContrast.pdf](http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/PrimacyOfLocalContrast.pdf)

For example, I recently shot a scene in which the darkest shadows were
on Zone III, and the brightest highlights (snow) were well into Zone
VIII.  Depending on how you do exposure control, this is either normal
development or slight N-.  The problem is that the dominant geometry
in the scene was a bunch of boards that - at best - showed a Subject
Brightness Range of about 3 stops.  This was the most important part of
the scene but, I was stuck with two bad choices:

- Normal, or worse still, contracted development would shove all these
  tones together to produce low local contrast in the mid-tones.
  i.e., A picture that held the entire tonal range, but boring because
  the primary image geometry had low local contrast.

- But if I did N+ development to improve middle tone contrast there
  was good chance the snow highlights would blow out to Zone IX or X.
  Because Pyrocat-HD is a semi-compensating developer, I likely would
  have been able to burn through this *if* I could control the burn
  geometry properly.

This is where a form of stand saved the day.  By developing the negative
using stand techniques, I was able to get full box film speed in the shadows,
jack up the mid-tone contrast, and preserve the highlights from getting
pushed up too far.

When reading about stand development, you'll run into a lot of
discussion of "edge effects".  These occur as a byproduct of the way
stand works chemically, especially when using Pyro staining
developers.  The edge effects show up as a line in a transition
between a light and dark subject.  In the extreme case, it can
actually manifest itself as a "halo" behind the transition.  (This is
one of the reasons you don't want to overdo stand development.)  This
edge effect is perceived by the human eye as higher sharpness.  It's
sort of an illusion, but it's a useful one.  (For those of you who do
digital post processing, this is approximately the chemical equivalent
of an unsharp mask.)

It's worth mentioning that there are other approaches to the problem
of holding highlights while expanding mid-tone contrast.  You can use
a lower contrast or "compensating" developer like D-23. This is
a very simple and inexpensive 2-component developer you can easily
mix yourself.

David Kachel - no fan of stand processing but a superb contributor to
this craft - has a novel technique called "SLIMT".  In a negative with
really bright top zones, he adjusts for shadow and mid-tones as
necessary, *and then mildly bleaches the negative* during the pre-soak
phase prior to development.  It's a novel technique and uses minimal
chemistry. I plan to also explore this at some point as well:

[http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/SLIMTs_Practical_Application.pdf](http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/SLIMTs_Practical_Application.pdf)


## So How Does It Work?

Stand techniques depend on a basic property of how film develops -
*The highlights develop much faster than the shadows.* One Kodak
engineer was heard to say that "Development ends after 3 minutes, the
rest of the time is spent increasing contrast." This is just another
way of saying the same thing.

As the highlights develop, they exhaust the developer around them much
faster than the shadow areas do.  In other words, the brighter the
object - say white snow - the quicker it will exhaust the nearby
developer.  The darker the object - say a shadow - the slower it will
exhaust.  Mid-Tones live, well, somewhere in the middle.

For those of you with a technical bent, I highly recommend a careful
reading of this explanation of film behavior by David Kachel:

[http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/HowFilmWorks.pdf](http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/HowFilmWorks.pdf)

Normally, we don't notice this because *we agitate regularly* thereby
replenishing the supply for fresh developer everywhere, most
especially the highlights that have "run out of" useful developer.

Stand development exploits this by ... *not agitating at all or very
little*.  Highlights are allowed to exhaust because they develop
quickly and don't really need more developer.  But by letting the film
sit in a really dilute developer solution for a looooooong time
without agitation, the shadows continue to develop and so do the mid
tones.  This means we are:

* Fully developing the shadows (getting full box speed ASA)
* Raising the H/D contrast curve for the mid-tones
* Doing little to the highest tones

In effect, stand techniques add two other things we can control about
how we develop film.  In addition to time and temperature, we now add
developer dilution and frequency/duration of agitation as development
controls.

It's worth mentioning that this is super tricky to get right.  In
the words of a retired Kodak film engineer, "Kodak did not consider
still development in formulating its films. It is not a recommended
practice."  That's right, it's not.  And you're not supposed to
tune your stock Ford engine to produce more horsepower either.  It
is not recommended by the manufacturer ;)


## What's The Downside?

As film develops, it produces chemical byproducts like bromides that
we usually don't notice because ... we're agitating regularly. This
serves to "wash away" these byproducts with fresh developer.  But when
you stand develop, these byproducts can come to rest on your negative
and interfere with the development.  This results in streaks and marks
on your negatives and can be entirely ruinous to the process.  That's
why the Great Yellow Father, Kodak, recommended so strongly against
this approach.  This mess is often referred to as "bromide drag".

All manner of techniques exist to avoid these problems, with varying degrees
of success.  Among them include:

* Developing and standing negatives in open trays
* Using specialty tubes made of PVC plumber's pipe to hold the negative during standing
* Using minimal contact hangers to hold the film during standing

Formally and properly, stand development should be done with the
negatives laying flat in a tray or the equivalent.  They should *stand
laying down* not hanging vertically in a tank.  My testing suggests
that this is not absolutely necessary and at least one other approach
will work.

It's also worth noting that the photographers who pioneered this
approach a hundred plus years ago were using very different films and
plates.  Modern thin films do have more a propensity for bromide drag
than their grandfather films did.

Still, this can be conquered and - at least in my view - should be in the
arsenal of tools for any advanced monochrome silver photographer.


## Terminology

There are many references to this sort of development in the literature
and the terminology isn't used consistently.  For our purposes we'll
define things as follows:

* **Normal Development** - Using developer at recommended dilutions and
  agitating regularly once or twice a minute.

* **Stand Development** - Using highly dilute developer, agitating
  vigorously for the first 1-2 minutes and then just letting the film
  sit untouched in the developer for 45-60 minutes or even more.

* **Semistand Development** - Using highly dilute developer, agitating
  vigorously for the first 1-2 minutes, and then once again for 10-15
  seconds at the development halfway point. So, for a 60 min stand,
  we'd agitate at the 30 min mark.

* **Extreme Minimal Agitation (EMA)** (Attributed to Steve
  Sherman). Using highly dilute developer, agitating for the first 1-2
  minutes, and then again for 10-15 seconds at 2 or 3 evenly spaced
  intervals for the remaining time.  Say we initially agitate for 2
  minutes and want a total development time 30 minutes.  We could
  split up the remaining 28 minutes into three intervals and do 10-15
  second agitations at 9 minutes, 16 minutes, and 23 minutes.

Semistand and EMA were conceived to overcome the nasty development
artifacts (artefacts if you live in the UK ;) like bromide drag.  The
occasional short agitation during stand development reduces the
likelihood you'll see these gremlins appear in your negatives.

Surprisingly, I discovered that even the single midpoint agitation of
a semistand development can increase apparent contrast and - in the
case of Pyrocat-HD - level of stain (as well as Film Base Plus
Fog). So each of these techniques has a place.


## How Did I Test?

I exposed and developed a variety of films using all four of the
development techniques above.  As I did so (and failed more often than
not) I began to do my down "dialing it" of what worked and what did
not.

* For all cases, I used Pyrocat-HD as the developer at a nominal
  68F/20C.

  I should mention that I designed and built my own
  temperature-sensitive timer to keep temperature considerations out
  of mind in the darkroom.  You can find the details here:

  [https://gitbucket.tundraware.com/tundra/devtimer](https://gitbucket.tundraware.com/tundra/devtimer)

  This is certainly not a requirement and you can do ordinary
  time/temperature corrections as usual in your own work.

* Pyrocat-HD is a developer mixed from two stock solutions. Dilution
  is expressed as `Part A : Part B : Water`.  For Normal development,
  dilution was `1:1:100`.  For the various stand tests, dilution
  was either `1.5:1:150` or `1.5:1:200`.

* Developer and fixer were mixed with distilled water.

* 4x5 films tested included Kodak TXT, Agfapan APX 100, and Ilford
  FP4+.  Not every film was tested with every agitation method, but
  across all film types, the tests covered stand, semistand, and
  extreme minimal agitation.

* I tested 120 Ilford FP4 as well as 35mm Tri-X and Agfapan APX 100.
  Both formats were tested using semistand in open half-gallon tanks
  with Nikor stainless developing reels.

* Development was in open tanks and - in a few cases - a Yankee 4x5
  tank with insert.

* A variety of different film suspension systems were tried including
  Kodak "framed" film hangars, a Yankee 4x5 tank, and a "frameless"
  Kodak film hanger.

* Film was presoaked for 5 minutes in running water to wash off the
  anti-halation layer and prepare the emulsion to accept developer.
  It's not clear this is entirely necessary with open tanks but it
  does no harm.


## What I Have Discovered

First of all, these are **my** findings, built on my workflow and darkroom
technique. These are intended to be guideposts, not definitive rules. They
are intended to be a starting point for you to explore, not some final
word in how to do this stuff.  Every statement below should be read
to say "In my case ..."

* Stand development is *really* fussy about how the film is held in
  the developer.  Framed hangers and the Yankee tank insert all showed
  bromide drag effects in varying and unpredictable ways.  My theory -
  which I cannot prove - is that turbulent effects and developer
  trapping is taking place along- and under the hangar frames/insert
  supports and promoting bromide drag.

* Semistand development is at lower risk of this, but still shows
  some evidence of bromide drag with framed hangers and tank inserts.

* For this reason, all my sheet film is now hung using old frameless
  Kodak hangers. They have minimal points of contact with the film.
  A likely viable alternative here would be a dental X-ray film clip.
  In either case, having more than one sheet in the tank will be
  tricky to agitate because there is no frame to keep it in place.
  Patience is your friend here.

  How good is this?  I was able to get a perfect negative with stand
  development (no agitation during stand period) using these hangers.

* Well... *almost* perfect.  The negative shows just a slight hint of
  bromide drag. It is at the end of that negative that was at the
  bottom of the tank - exactly where gravity would land it.  The exact
  same scene exposed identically but processed with EMA and semistand
  do not show this artifact.

* In short, *I was unable to consistently get stand processing to
  produce artifact-free negatives*. So, even with better film
  suspension, at least one midpoint agitation is a really good idea.
  This is confirmed in discussions with other photographers doing this
  sort of thing, even in trays.  (Almost) no one is getting decent
  results with pure stand.  The issue here isn't that stand doesn't
  work.  The issue is that stand doesn't work **consistently**.

  As a practical matter, there is no reason to do stand over semistand
  or EMA.  Both of the latter techniques give good results.

* I did some testing with 35mm and 120 on stainless steel reels, but
  dunked into open 4x5 tanks rather than the usual daylight tanks
  favored by small format shooters. As expected, Normal development
  worked fine.  To my surprise, semistand was OK as well.  I was
  expecting bromide drag problems because of the way the reels support
  the film.  Again, I think strong initial agitation helped here.

  I've also noticed a considerable difference of reel spacing from
  different manufacturers.  If you are going to do 35mm or 120 this
  way, I'd stick with the old Nikor reels.  They're a bit expensive
  but widely available on eBay.  I'd also recommend doing these
  smaller formats in an open tank, rather than the smaller stainless
  tanks that are normally used with these.  Why?  Because you'll get
  more developer around the film no matter what the agitation model.
  It does mean working in the dark, though.  Under no circumstance
  would I use the adjustable plastic reels sometimes found in cheaper
  kit.  The ridges for holding the film in place are tall and inhibit
  smooth developer flow. Using this just begs for bromide drag
  problems.

* Stand and semistand did best with the `1.5:1:200` dilution.  EMA did
  best with the `1.5:1:150` dilutions.  This makes sense, since EMA
  times tend to be a lot shorter than true stand development and more
  dilute developers will take longer to act on the shadows.

* Both stand and semistand really need 45-60 minutes to fully do their
  jobs.

* Both stand and semistand need a full 2 minutes of initial agitation
  and it needs to be "vigorous".  Again, I suspect - but cannot prove -
  that really kicking the development off hard at the beginning reduces
  the likelihood of bromide drag later.

* EMA was fine with only 90 seconds of more normal initial agitation.

* The single agitation introduced at the midpoint in semistand
  development seems to noticeably reduce the risk of bromide
  drag.

* The single agitation introduced by semistand development seems to
  increase overall contrast and density as compared to a no-agitation
  stand period.  It's not night and day, but given that doing this
  reduces the risk of bromide drag, it's probably the preferred long
  stand technique and this extra contrast has to be considered.

* Given a normal dilution of `1:1:100` and an EMA dilution of `1.5:1:150`,
  I found that a good first order guess for EMA development time was
  to double my Normal development time with 2 or 3 equally spaced
  agitations during the stand time.

* You can do contrast control with EMA much like you do with Normal
  development - increase- or decrease overall time.  With stand and
  semistand, it's a bit more difficult because you really want that
  long development time to fill in the shadows and crank up the mid-tones.
  I've not tried it, but changing developer dilution is likely a better
  tactic for these development methods.

* You can overdo this. If you have a scene that already has good
  mid-tone local contrast, these techniques can give you a  cartoon-like
  local contrast expansion.

* All the stand techniques gave me full box speed ASA for every film
  I tried.

* You have to be merciless to "expose for the shadows" properly.  If
  you underexpose, nothing can save you. You cannot develop content
  that isn't present in the negative.  If you overexpose, you will get
  the entire tonal range of the image sliding up the H/D curve in ugly
  ways with stand techniques.  In this regard, exposure control and
  ASA management is much more demanding than most conventional
  film-developer Normal development methods.


## Is It Worth It?

Yes, in certain cases.  Low- or no agitation development is slow and
finicky.  But, it really shines when you want to emphasize mid-tone
local contrast, but have a competing highlight that would get blown
out (or hard to print) if you just did N+ Development.

More generally, these techniques are great when you need to get
maximum shadow detail, but reign in highlight placement.

Stand techniques also work nicely when you want to get best apparent
sharpness on subjects that show a lot of bright-to-dark transition
lines - for example, articulated rock faces.

Think of stand as another arrow in your quiver.  You won't always use it, but
it can be a really nice enhancement to your arsenal of tools.

I **strongly** recommend that, if you're going to try this, take at
least two exposures (on separate sheets or rolls) of every scene
you care about.  Try one with stand techniques, and have a backup you
can process normally if needed.


## Updates

New findings since the document first went live can be found below.

### Update 6-3-2021: Very Old Film

Since this was first written, I've done a fair bit of testing using low
agitation with very old, expired film.  So far, I've discovered
several things worth noting:


* Old Kodak Tri-X (expired 7/1993) takes semistand processing
  in Pyrocat-HD perfectly, shows full speed, and has no noteable fog.

* Very old Kodak Plus-X (expired 11/1974) is another matter.  It shows
  horrible bromide drag at the hanger suspension locations - even
  using the most minimal support.

  Whether this is the nature of this film or its age isn't clear.  I
  have to do further testing with other Plus-X vintages.  What is
  clear is that this is definitely induced by the Pyrocat-HD.  When I
  took the same film/scene and semistand processed it in D-23 1:1 for
  60 minutes, I got perfect negatives that actually showed slightly
  better film speed than the Pyrocat-HD negs.


### Update 8-29-2021: Very VERY Old Film

I was interested in seeing how this worked with really old film
and explore just how "old" was too old:


* So, I shot some sheets of 2x3 Kodak Super-XX (expired 1/1961).
  That's right, this film has been out of date for over *60 years*.  I
  used both Pyrocat-HD 1.5:1:200 and D-23 1:1 to semistand process a
  couple of these negatives.

* The results?  Perfectly printable negatives.  The Pyrocat produced a
  bit more negative fog, but noticably less visible grain.  The D-23
  produced a "cleaner" negative, but had a lot more grain.  It's worth
  noting that Super-XX was always a rather grainy film and was pretty
  much replaced by Tri-X in short order, particularly for smaller
  formats.  Both developers produced the full box ASA 200.

* Unsurprisingly, there were non-development artifacts due to the
  physical deterioration of the film.  The sheets were stuck together
  a bit in the box and I did see some mottling on the non-emulsion
  side of the film. This resulted in some spots in the final negative.

* All-in-all this demonstrates several things.  First of all,
  "reasonably" out-of-date film can pretty much be used as if it were
  new.  Secondly, semistand processing may offer a path for rescuing
  "found" old films.


### Update 12-18-2021: Low Agitation With Super-Dilute HC-110

I wanted to see how super-dilute HC-110 behaved when agitated
minimally.  Officially, the Kodak datasheet stops at 1:79 (Dilution
F). But I wanted to see if very high dilution and minimal agitation
worked well with this well regarded staple of the darkroom.

For this test, I exposed a 120 roll of Arista 100 at ASA 100.  The
film reel was elevated from the bottom of a Kodak 1/2 gal rubber tank
with a stopper to try to keep it away from any residual bromide
byproducts.

1/2 gallon of HC-110 was diluted 1:128.  The film was prewashed for 3
minutes then placed in the developer.  It was initially agitated
continuously for 2 minutes and then left to stand.  At 31 minutes,
another 15 seconds of agitation was applied.   The film was removed
from developer at 60 minutes and fixed/washed as usual.

Findings:

* The film developed nicely with no evidence of bromide drag and hit
  full box ASA as one might expect.

* Compared to Pyrocat-HD negatives, this seems to so very slightly more
  grain (not surprising) compared to other ASA 100 films.  However, I've
  not processed Arista 100 rollfilm in Pyrocat-HD so it could also just
  be how the film is made.

* The biggest thing I noticed is that super-dilute HC-110 has some
  highlight compensating effect but it is noticeably less pronounced
  than Pyrocat-HD.  I'd guess this is because of the lack of staining
  effect.

  One of the test scenes has deep shadows in a building directly
  illuminated by late afternoon sun.  There was probably something
  like a 13-15 stop subject brighness range.  Pycocat-HD would have
  handled those highlights just fine, but the super-dilute HC-110
  yielded a thick, dense negative.  It WAS printable and there WAS
  detail in the highlights, so the highlight exhaustion inherent in
  low agitation development definitely came into play.  It just wasn't
  as pronounced a correction as I am used to.  (It made the negative
  super fun to print with 100 seconds of soft light required to punch
  through the highlight density.)

Although this will never be my own daily driver, it would be useful
for teaching low agitation - you likely don't want students poking
around in catechol laced solutions until they understand what they are
doing.

As an aside, HC-110 and D-76 have very similar behaviours.  It might
be fun to try super dilute D-76 some time.


## Copyright And Use

All content here is Copyright (c) 2021 TundraWare Inc., Des Plaines, IL USA

Permission is hereby granted for non-commercial redistribution by any
means so long as you agree to these conditions:

* You agree to hold TundraWare Inc. harmless for any damage these
  techniques may cause.

* You agree to reproduce this monograph in full with full attribution
  of authorship.

* You agree to include the URL of this monograph in your copy.
